@@ -504,6 +504,9 @@ def engine_status(name_or_id: str, env: Optional[str]):
         else:
             click.echo(f"State: {engine_state}")  # No color for unknown states
 
+        # Show account (environment)
+        click.echo(f"Account: {env}")
+
         if status_data.get("launch_time"):
             click.echo(f"Launched: {format_time_ago(status_data['launch_time'])}")
 
@@ -565,6 +568,9 @@ def list_engines(env: Optional[str]):
         result = client.list_engines()
         engines = result.get("engines", [])
 
+        # Show account header with blue account name
+        click.echo(f"Engines for AWS Account \033[34m{env}\033[0m\n")
+
         if not engines:
             click.echo("No engines found")
             return
@@ -583,8 +589,14 @@ def list_engines(env: Optional[str]):
             engine_type = engine.get("engine_type", "unknown")[:11]
             instance_id = engine.get("instance_id", "unknown")
 
+            # Color the state in the list view
+            if state == "running":
+                state_display = f"\033[32m{state:<12}\033[0m"
+            else:
+                state_display = f"{state:<12}"
+
             click.echo(
-                f"{name:<12} {state:<12} {user:<12} {engine_type:<12} {instance_id:<20}"
+                f"{name:<12} {state_display} {user:<12} {engine_type:<12} {instance_id:<20}"
             )
 
         click.echo(f"\nTotal: {len(engines)} engine(s)")
@@ -832,7 +844,7 @@ def idle_timeout_cmd(
 
         # Show current settings
         idle_state = status.get("idle_state", {})
-        timeout_seconds = idle_state.get("timeout_seconds", 1800)
+        timeout_seconds = int(idle_state.get("timeout_seconds", 1800))
         timeout_minutes = timeout_seconds // 60
 
         click.echo(f"\nIdle Settings for '{engine_name}':")
